@@ -23,7 +23,7 @@ use Data::Dumper;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '0.46';
+$VERSION = '0.47';
 
 =head1 NAME
 
@@ -502,7 +502,9 @@ sub getcmd {
             }
          }
          if ($opt eq '_args') {
-            push @{$runopts{$opt}}, @{$execopts->{$opt}};
+            # only preserve order if we already have order
+            push @{$runopts{$opt}}, @{$execopts->{$opt}}
+               if @{$runopts{$opt}};
          } elsif ($opt eq 'source' or $opt eq 'dest') {
             $runopts{$opt} = $execopts->{$opt};
          } else {
@@ -514,7 +516,7 @@ sub getcmd {
    }
 
    if (
-      !$merged->{_args}    # include and exclude allowed if ordered args
+      !@{$merged->{_args}}    # include and exclude allowed if ordered args
       && ( (@{$merged->{list}{exclude}} != 0)
          + (@{$merged->{list}{include}} != 0)
          + (@{$merged->{list}{filter}} != 0) > 1)
@@ -531,7 +533,7 @@ sub getcmd {
    # build the real command
    my @cmd = ($merged->{_perlopts}{'path-to-rsync'});
 
-   if ($merged->{_args}) {    # prefer ordered args if we have them
+   if (@{$merged->{_args}}) {    # prefer ordered args if we have them
       my $gotsrc;
       for (my $e = 0; $e < @{$merged->{_args}}; $e += 2) {
          my $key = $merged->{_args}[$e];
